package com.ruoyi.supplier.service;

import java.util.List;
import com.ruoyi.supplier.domain.TCanteenQualification;

/**
 * 供应商资质Service接口
 * 
 * @author ruoyi
 * @date 2025-04-22
 */
public interface ITCanteenQualificationService 
{
    /**
     * 查询供应商资质
     * 
     * @param qualificationId 供应商资质主键
     * @return 供应商资质
     */
    public TCanteenQualification selectTCanteenQualificationByQualificationId(Long qualificationId);

    /**
     * 查询供应商资质列表
     * 
     * @param tCanteenQualification 供应商资质
     * @return 供应商资质集合
     */
    public List<TCanteenQualification> selectTCanteenQualificationList(TCanteenQualification tCanteenQualification);

    /**
     * 新增供应商资质
     * 
     * @param tCanteenQualification 供应商资质
     * @return 结果
     */
    public int insertTCanteenQualification(TCanteenQualification tCanteenQualification);

    /**
     * 修改供应商资质
     * 
     * @param tCanteenQualification 供应商资质
     * @return 结果
     */
    public int updateTCanteenQualification(TCanteenQualification tCanteenQualification);

    /**
     * 批量删除供应商资质
     * 
     * @param qualificationIds 需要删除的供应商资质主键集合
     * @return 结果
     */
    public int deleteTCanteenQualificationByQualificationIds(Long[] qualificationIds);

    /**
     * 删除供应商资质信息
     * 
     * @param qualificationId 供应商资质主键
     * @return 结果
     */
    public int deleteTCanteenQualificationByQualificationId(Long qualificationId);
}
